/** 
 * @file   DFBiokey3000.h
 * @author Bernd Ottmann, Maik Siebrand
 * @date   05.06.2008
 * @brief  Deklarationen der Exportroutinen.
 * @note   Die Auflistung der Routinen ist wie in der zugehoerigen Dokumentation.
 */
//////////////////////////////////////////////////////////////////////
#ifndef _DFBIOKEY3000_H_
#define _DFBIOKEY3000_H_

/** 
 @mainpage Dokumentation zur DFBiokey3000.dll.
 <center> @code 

   ########################################################
   ##       |                   |                  |     ##
   ##                          \_/                       ##
   ##       |                 -(_)-                |  \  ##
   ##                          / \                    |\\##
   ##  /|   |                                      |  || ##
   ##/ ||                  _\|||/_                    || ##
   ##  ||   |               /_=_\                  |  || ##
   ##  ||                  ({}-{})                    || ##
   ##  ||   |+-----oOo-------(_)---------------+   |  || ##
   ## //     |                                 |      || ##
   ##/      ||          Datafox GmbH           |   |  || ##
   ##        |                                 |      || ##
   ##       |+-------------------------oOo-----+   |  || ##
   ##                     |  |~|  |                   || ##
   ##       |_ __ _ __ _ _|__| |__|_ __ _ __ _ __ _|  || ##
   ##      /               ||   ||                  \ || ##
   ##    /               .ooO   Ooo.                  \ \##
   ##  /                                                \##
   ########################################################

 @endcode </center>
 @author Bernd Ottmann
 @author Maik Siebrand
 @date   05.06.2008
 @version 1.0.0.1
*/

// ########################################################
// ###################### DEFINES #########################
// ########################################################

/**
 * Gibt export oder import der Routinen an. Siehe auch EXTERN_DECL.
 *
 * @todo Mit 1 im Quelltext vor #include zu definieren um die Routinen als Import zu erhalten.
 *
 * @code #define AE3COM_EXPORT   1 @endcode
 */
#ifndef DLL_EXPORT
	#define DLL_EXPORT 0
#endif

#ifndef USE_PRIVATE
	#define USE_PRIVATE   0
#endif

// Eventuell fehlende typedefs ersetzen
#ifdef _WIN32

#ifndef HANDLE
	#define HANDLE void*
#endif

#endif
// ++++++++++++++++++++++++++++++++++++++++++++++++++++++++
// +------------+ EXPORTIERTE FUNKTIONEN +----------------+
// ++++++++++++++++++++++++++++++++++++++++++++++++++++++++

/**
 @def EXTERN_DECL Gibt den Praefix fuer Funktionen an. (Dekorierung und Export-, Importangabe)
*/

#ifdef _WIN32

#if (DLL_EXPORT)
	// Einzubindende Bibliotheken: Version.lib, WSock32.lib
	#define EXTERN_DECL         extern "C" __declspec(dllexport)
#else
	#define EXTERN_DECL         extern "C" __declspec(dllimport)
#endif

#else

#define EXTERN_DECL             extern "C"

#ifdef __declspec
	#undef __declspec
#endif

#define __declspec(dllexport)

#ifdef __stdcall
	#undef __stdcall
#endif

#define __stdcall

#endif

// ########################################################
// ############## ALLGEMEINE FUNKTIONEN ###################
// ########################################################



/*###########################################################*/
//  FUNKTION:	  DFBComOpen
/** ffnet die RS232

 Autor                 : Maik Siebrand             @n 
 Autor                 : Bernd Ottmann             @n 
 erstellt am           : 25.10.2006                @n
 letzte nderung vom   : 06.06.2008                @n

@param[in] commStr Sendestring COM1, COM2 ...
@return Erfolgsmeldung = TRUE, Fehlerfall = FALSE
  
@b AUFGABE:    
- ffnet die RS232 falls mglich.
	
@b NDERUNG:
- 06.06.2008 (MS) bergabe String mit Schnittstellenbezeichnung
		
@b TEST :     
- 25.10.2006 (MS) keine Fehler festgestellt @n
- 06.06.2008 (MS) keine Fehler festgestellt @n
*/  
/*###########################################################*/

EXTERN_DECL int __stdcall DFBComOpen(char *commStr);

/*###########################################################*/
//  FUNKTION:	  DFBGetLastErrorNum
/** Gib den letzten Fehlercode zurck

Autor                 : Maik Siebrand             @n
erstellt am           : 06.06.2008                @n
letzte nderung vom   : XX.XX.200x                @n


@return Fehlercode 

@b AUFGABE:    
- Gibt die Nummer des letzten Fehlers zurck

@b Fehlercodes: 
-# ComPort Open Error / Fehler beim ffnen der Schnittstelle
-# ComPort Settings Error / Biokey 3000 kann nicht erreicht werden
-# Communication Error / Biokey 3000 antwortet nicht auf Anfrage
-# Scann Error / Scann Fehler, Qualitt oder Minuzinanzahl zu schlecht
-# Template Format Error / Formatfehler beim Template
-# Template Buffer Size to small / vorgegebener Templatepuffer ist zu klein

@b TEST :     
- 06.06.2008 (MS) keine Fehler festgestellt @n


*/
/*###########################################################*/
EXTERN_DECL int __stdcall DFBGetLastErrorNum(void);

/*###########################################################*/
//  FUNKTION:	  DFBComClose
/** Schliet die RS232

Autor                 : Maik Siebrand             @n 
erstellt am           : 25.10.2006                @n
letzte nderung vom   : XX.XX.2006                @n

@b AUFGABE:    
- Schliet die RS232


@b TEST :     
- 25.10.2006 (MS) keine Fehler festgestellt @n
- 06.06.2008 (MS) keine Fehler festgestellt @n

*/  
/*###########################################################*/
EXTERN_DECL void __stdcall DFBComClose();

/*############################################################################*/
//  FUNKTION:	 DFBInit
/** Initialisierung des BioKey3000

Autor                 : Maik Siebrand             @n
erstellt am           : 06.06.2008                @n
letzte nderung vom   : xx.xx.xxxx                @n

@param[in] TemplateFormat 0 -DIN-Format, 1 Idencom Compact Format
@param[in] SecurityLevel Sicherheitslevel, das sich aus Falschrueckweisungrate und Falschakzeptanzrate ergibt
@param[in] Quality Mindestqualitt der Templates
@param[in] MinutiaeMin Mindestanzahl der Minuzien


@return Erfolgsmeldung = TRUE, Fehlerfall = FALSE

@b AUFGABE:    
- Sendet die wichtigsten Einstellungen aus dem Setup zum BioKey.


@b TEST :
- 06.06.2008 (MS) keine Fehler festgestellt @n


*/
/*############################################################################*/

EXTERN_DECL int __stdcall DFBInit(unsigned char TemplateFormat, unsigned char SecurityLevel, unsigned char Quality, unsigned char MinutiaeMin);

/*###########################################################*/
//  FUNKTION:	  DFBScanFinger
/** Scannt einen Finger in TemplateBufferA(Sensorbuffer FTP_BUF)

Autor                 : Maik Siebrand             @n
erstellt am           : 06.06.2008                @n

@param[in] BestScann 0..1 fr einen Scann 2..10 Anzahl der Scanversuche fr den besten Fingerscann

@return Erfolgsmeldung = TRUE, Fehlerfall = FALSE

@b AUFGABE:    Scannt einen Finger ein und gibt wenn die Qualitt ausreichend war
               ein OK zurck. Die Funktion kann durch Drcken der ESC-Taste 
               abgebrochen werden.
               Die BestScann Variable gibt an ob aus mehreren Scanns das beste 
               Templatenach Beendigung der funktion im Templatepuffer zurck-
               gehalten wird.


@b TEST :
- 06.06.2008 (MS) keine Fehler festgestellt @n

*/
/*###########################################################*/

EXTERN_DECL int __stdcall DFBScanFinger(unsigned char BestScann);

/*###########################################################*/
//  FUNKTION:	  DFBGetTemplate
/** liest den TemplateBufferA(Sensorbuffer FTP_BUF) aus

Autor                 : Maik Siebrand             @n
erstellt am           : 06.06.2008                @n

@param[in] BufferSize Gre des im System vorgehaltenen Speichers fr das Template
@param[out] Buffer Templatepuffer 161Byte fr DIN-Format und 216 Byte fr Idencom Compact Format

@return Erfolgsmeldung = TRUE, Fehlerfall = FALSE

@b AUFGABE:    Liest einen Finger aus dem Templatebuffer A aus 
               und prft vorher die Puffergre ab.               


@b TEST :
- 06.06.2008 (MS) keine Fehler festgestellt @n

*/
/*###########################################################*/

EXTERN_DECL int __stdcall DFBGetTemplate(unsigned int *BufferSize, unsigned char *Buffer);



#endif

